/*
 * Copyright 2003 - 2010 The eFaps Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Revision:        $Rev: 5421 $
 * Last Changed:    $Date: 2010-08-26 13:41:01 -0500 (Thu, 26 Aug 2010) $
 * Last Changed By: $Author: jan.moxter $
 */

package org.efaps.admin.datamodel.ui;

import java.io.Serializable;

import org.efaps.admin.datamodel.Attribute;
import org.efaps.util.EFapsException;

/**
 * Abstract class for the UIInterface interface implementing for all required
 * methods a default.
 *
 * @author The eFaps Team
 * @version $Id: AbstractUI.java 5421 2010-08-26 18:41:01Z jan.moxter $
 */
public abstract class AbstractUI
    implements UIInterface, Serializable
{
    /**
     * Needed for serialization.
     */
    private static final long serialVersionUID = 1L;

    /**
     * {@inheritDoc}
     */
    @Override
    public String getEditHtml(final FieldValue _fieldValuee)
        throws EFapsException
    {
        return "edit";
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getHiddenHtml(final FieldValue _fieldValue)
        throws EFapsException
    {
        return "hidden";
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getReadOnlyHtml(final FieldValue _fieldValue)
        throws EFapsException
    {
        return "read only";
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getStringValue(final FieldValue _fieldValue)
        throws EFapsException
    {
        return getReadOnlyHtml(_fieldValue);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Object getObject4Compare(final FieldValue _fieldValue)
        throws EFapsException
    {
        return null;
    }

    /**
     * {@inheritDoc}
     * @throws EFapsException
     */
    @Override
    public int compare(final FieldValue _fieldValue,
                       final FieldValue _fieldValue2)
        throws EFapsException
    {
        return 0;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String validateValue(final String _value,
                                final Attribute _attribute)
        throws EFapsException
    {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Object format(final Object _object,
                         final String _pattern)
        throws EFapsException
    {
        return _object;
    }
}
